@@ -10,8 +10,6 @@
 #include <kwallet.h>
 #include <QDBusConnectionInterface>
 #include <QDBusConnection>
-#include <QDBusReply>
-#include <KLocalizedString>
 
 #include "kwallettest.h"
 
